# frozen_string_literal: true
require 'hammerhead'
require 'hammerhead/configuration'
require 'hammerhead/utils'
require 'hammerhead/version'

require 'harvest'

require 'tty-logger'

##
# Wraps the functionality of the hammerhead tool. Contains the commands
# defined, and implemented, by the +tty+ gem.
#
module Hammerhead
  ##
  # Commands generated by the +tty+ gem are organized in this module.
  #
  module Commands; end

  ##
  # General error used when something bad, or unexpected, occurs.
  #
  class Error < StandardError; end

  class << self
    ##
    # Returns a Hammerhead::Configuration instance
    #
    def configuration
      @configuration ||= Hammerhead::Configuration.new
    end

    ##
    # Returns a TTY::Logger instance
    #
    def logger
      @logger ||= TTY::Logger.new
    end

    ##
    # Provides an alternate way to access the +configuration+
    def configure
      yield configuration
    end
  end
end
